Hepos co-ordinate transformations
=================================

This is a Python library to convert geographical co-ordinates between
the old GGRS87 (ΕΓΣΑ87) and newer co-ordinate reference systems, using
the HEPOS transformation algorithms described at http://hepos.gr/.

The library at the moment is at an early stage and does not include
the steps that involve corrections with the correction grid. Thus, its
accuracy is at about 1 m.

© 2013 Ministry of Environment of Greece

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see http://www.gnu.org/licenses/.
